@@ -61,7 +61,7 @@ extern "C" {
 /* PLVERSION_TAG: a string, normally "", but for example "rc1" */
 
 #ifndef PLVERSION
-#define PLVERSION 90329
+#define PLVERSION 100103
 #endif
 #ifndef PLVERSION_TAG
 #define PLVERSION_TAG ""
@@ -210,11 +210,7 @@ typedef _PLS(PL_local_data) *PL_engine_t; /* opaque engine handle */
 typedef _PLQ(word)	PL_atomic_t;	/* same a word */
 typedef uintptr_t	foreign_t;	/* return type of foreign functions */
 typedef wchar_t		pl_wchar_t;	/* Prolog wide character */
-#ifdef __cplusplus
-typedef void *		pl_function_t;      /* pass function as void* */
-#else
-typedef foreign_t	(*pl_function_t)(); /* foreign language functions */
-#endif
+typedef void *		pl_function_t;  /* pass function as void* */
 typedef uintptr_t	buf_mark_t;	/* buffer mark handle */
 
 #define fid_t PL_fid_t			/* avoid AIX name-clash */
@@ -520,6 +516,9 @@ PL_EXPORT(void)		PL_unregister_atom(atom_t a);
 PL_EXPORT(size_t)	PL_atom_index(atom_t index);
 PL_EXPORT(atom_t)	PL_atom_from_index(size_t a);
 #ifdef O_DEBUG_ATOMGC
+#if defined(_MSC_VER) && !defined(__PRETTY_FUNCTION__)
+#define __PRETTY_FUNCTION__ __FUNCSIG__
+#endif
 #define PL_register_atom(a) \
 	_PL_debug_register_atom(a, __FILE__, __LINE__, __PRETTY_FUNCTION__)
 #define PL_unregister_atom(a) \
@@ -768,8 +767,9 @@ typedef struct PL_blob_t
   atom_t		(*load)(IOSTREAM *s);
   size_t		padding;	/* Required 0-padding */
 					/* private */
-  void *		reserved[9];	/* for future extension */
-  int			registered;	/* Already registered? */
+  void *		reserved[8];	/* for future extension */
+  int			(*write_ex)(atom_t a, void *context);
+  bool			registered;	/* Already registered? */
   int			rank;		/* Rank for ordering atoms */
   struct PL_blob_t *    next;		/* next in registered type-chain */
   atom_t		atom_name;	/* Name as atom */
@@ -1026,7 +1026,7 @@ PL_EXPORT(IOSTREAM *) _PL_stream(int which);
 #define Scurrent_output _PL_stream(4)
 #endif
 
-#define PL_WRT_QUOTED		       0x01 /* quote atoms */
+#define PL_WRT_QUOTED		       0x01 /* quote atoms and strings */
 #define PL_WRT_IGNOREOPS	       0x02 /* ignore list/operators */
 #define PL_WRT_NUMBERVARS	       0x04 /* print $VAR(N) as a variable */
 #define PL_WRT_PORTRAY		       0x08 /* call portray */
@@ -1057,6 +1057,9 @@ PL_EXPORT(IOSTREAM *) _PL_stream(int which);
 #define PL_WRT_QUOTE_NON_ASCII	   0x800000 /* Quote atoms containing non-ascii */
 #define PL_WRT_PARTIAL		  0x1000000 /* Partial output */
 #define PL_WRT_NO_CHARESCAPES	  0x2000000 /* Do not Output ISO escapes */
+#define PL_WRT_INFIX_COMMA	  0x4000000 /* Write (a,b), with PL_WRT_IGNOREOPS */
+
+#define PL_WRT_PORTABLE (PL_WRT_IGNOREOPS|PL_WRT_INFIX_COMMA)
 
 PL_EXPORT(bool)	PL_write_term(IOSTREAM *s,
 			     term_t term,
@@ -1118,8 +1121,8 @@ PL_EXPORT(int)		PL_dlclose(void *handle);
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 NOTE: the functions in this section are   not  documented, as as yet not
-adviced for public usage.  They  are   intended commandline editors such
-as GNU readline or libedit.
+adviced for public usage.  They are  support commandline editors such as
+libedit.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
 PL_EXPORT(void)		PL_add_to_protocol(const char *buf, size_t count);
@@ -1341,7 +1344,7 @@ typedef struct
 
 
 PL_EXPORT(int)	PL_thread_self(void);	/* Prolog thread id (-1 if none) */
-PL_EXPORT(int)	PL_unify_thread_id(term_t t, int i);
+PL_EXPORT(int)	PL_unify_thread_id(term_t t, int i); /* -1 if i is invalid */
 PL_EXPORT(bool)	PL_get_thread_id_ex(term_t t, int *idp);
 PL_EXPORT(bool)	PL_get_thread_alias(int tid, atom_t *alias);	/* Locks alias */
 PL_EXPORT(int)	PL_thread_attach_engine(PL_thread_attr_t *attr);
@@ -1349,9 +1352,11 @@ PL_EXPORT(bool)	PL_thread_destroy_engine(void);
 PL_EXPORT(bool)	PL_thread_at_exit(void (*function)(void *),
 				  void *closure,
 				  bool global);
-PL_EXPORT(int)	PL_thread_raise(int tid, int sig);
+PL_EXPORT(bool)	PL_thread_raise(int tid, int sig);
 #if defined(_WINDOWS_) || defined(_WINDOWS_H)	/* <windows.h> is included */
 PL_EXPORT(bool)	PL_w32thread_raise(DWORD dwTid, int sig);
+#endif
+#ifdef __WINDOWS__
 PL_EXPORT(bool)	PL_w32_wrap_ansi_console(void);
 PL_EXPORT(const char*) PL_w32_running_under_wine(void);
 #endif
@@ -1399,15 +1404,15 @@ typedef uint64_t table_value_t;
 
 PL_EXPORT(hash_table_t)	PL_new_hash_table(size_t size,
 					  void (*free_symbol)(table_key_t n, table_value_t v));
-PL_EXPORT(int)		PL_free_hash_table(hash_table_t table);
+PL_EXPORT(bool)		PL_free_hash_table(hash_table_t table);
 PL_EXPORT(table_value_t) PL_lookup_hash_table(hash_table_t table, table_key_t key);
 PL_EXPORT(table_value_t) PL_add_hash_table(hash_table_t table,
 					   table_key_t key, table_value_t value, int flags);
 PL_EXPORT(table_value_t) PL_del_hash_table(hash_table_t table, table_key_t key);
-PL_EXPORT(int)		PL_clear_hash_table(hash_table_t table);
+PL_EXPORT(bool)		PL_clear_hash_table(hash_table_t table);
 PL_EXPORT(hash_table_enum_t) PL_new_hash_table_enum(hash_table_t table);
 PL_EXPORT(void)		PL_free_hash_table_enum(hash_table_enum_t e);
-PL_EXPORT(int)		PL_advance_hash_table_enum(hash_table_enum_t e,
+PL_EXPORT(bool)		PL_advance_hash_table_enum(hash_table_enum_t e,
 						   table_key_t *key, table_value_t *value);
 
 
@@ -1416,15 +1421,15 @@ PL_EXPORT(int)		PL_advance_hash_table_enum(hash_table_enum_t e,
 		 *******************************/
 
 typedef struct
-{ int	(*unify)(term_t t, void *handle);	/* implementation --> Prolog */
-  int   (*get)(term_t t, void **handle);	/* Prolog --> implementation */
-  void	(*activate)(int active);		/* (de)activate */
+{ bool	(*unify)(term_t t, void *handle);	/* implementation --> Prolog */
+  bool  (*get)(term_t t, void **handle);	/* Prolog --> implementation */
+  void	(*activate)(bool active);		/* (de)activate */
   void  (*release)(void *handle);		/* Release handle */
   void *dummy[4];				/* reserved */
   intptr_t	magic;				/* PROFTYPE_MAGIC */
 } PL_prof_type_t;
 
-PL_EXPORT(int)		PL_register_profile_type(PL_prof_type_t *type);
+PL_EXPORT(bool)		PL_register_profile_type(PL_prof_type_t *type);
 PL_EXPORT(void*)	PL_prof_call(void *handle, PL_prof_type_t *type);
 PL_EXPORT(void)		PL_prof_exit(void *node);
 
@@ -1484,8 +1489,8 @@ typedef struct pl_context_t
   void *	reserved[10];		/* Reserved for extensions */
 } pl_context_t;
 
-PL_EXPORT(int)	PL_get_context(struct pl_context_t *c, int thead_id);
-PL_EXPORT(int)	PL_step_context(struct pl_context_t *c);
+PL_EXPORT(bool)	PL_get_context(struct pl_context_t *c, int thead_id);
+PL_EXPORT(bool)	PL_step_context(struct pl_context_t *c);
 PL_EXPORT(int)	PL_describe_context(struct pl_context_t *c,
 				    char *buf, size_t len);
 
